phoopy-yaml
=============

|Build Status| |Version| |Pyversions|

Yaml parsing library for phoopy framework


.. |Build Status| image:: https://travis-ci.org/phoopy/phoopy-yaml.svg
   :target: https://travis-ci.org/phoopy/phoopy-yaml

.. |Version| image:: https://badge.fury.io/py/phoopy-yaml.svg
   :target: https://pypi.python.org/pypi/phoopy-yaml

.. |Pyversions| image:: https://img.shields.io/pypi/pyversions/phoopy-yaml.svg
   :target: https://pypi.python.org/pypi/phoopy-yaml
